@@ -4,7 +4,7 @@
     has_data <- requireNamespace("hurricaneexposuredata", quietly = TRUE)
     .pkgenv[["has_data"]] <- has_data
 }
-    
+
 .onAttach <- function(libname, pkgname) {
     if (!.pkgenv$has_data) {
         msg <- paste("To use this package, you must install the",
@@ -23,7 +23,6 @@ hasData <- function(has_data = .pkgenv$has_data) {
                      "`hurricaneexposuredata` package installed. See the",
                      "`hurricaneexposure` package vignette for more details.")
         msg <- paste(strwrap(msg), collapse="\n")
-        message(msg)
-        return(invisible(NULL))
+        stop(msg)
     }
 }
